@@ -8,8 +8,8 @@
 ;; Keywords: calendar
 ;; URL: https://github.com/TomoeMami/org-repeat-by-cron.el
 
-;; Package-Version: 1.0.3
-;; Package-Revision: 5d780367bf5d
+;; Package-Version: 1.0.4
+;; Package-Revision: 414d872ed716
 ;; Package-Requires: ((emacs "24.4"))
 
 ;; This file is not part of GNU Emacs.
@@ -376,8 +376,8 @@ a comma-separated list:
           (cl-some
            (lambda (part)
              (cond
-              ;; Format: L5 or L7 -> last Friday/Sunday
-              ((string-match "L\\([0-7]\\)" part)
+              ;; Format: 5L or 7L -> last Friday/Sunday
+              ((string-match "\\([0-7]\\)L" part)
                (let* ((target-dow (string-to-number (match-string 1 part)))
                       ;; If it's 7, convert to 0 (Sunday)
                       (final-dow (if (= target-dow 7) 0 target-dow)))
